@@ -232,10 +232,10 @@ class AbstractBaseAliasChangeSerializer(serializers.Serializer):
                         # Has the appropriate alias type
                         if hasattr(user, self.alias_field_name):
                             # Check, isn't alias the same.
-                            alias = attrs.get(self.alias_type)
+                            alias = request.get(self.alias_type)
                             if getattr(user, self.alias_field_name) == alias:
                                 msg = _(
-                                    f'This user already have this {self.alias_type}.'
+                                    f'This user already have same {self.alias_type}.'
                                 )
                             else:
                                 attrs['user'] = user
@@ -486,6 +486,11 @@ class CallbackTokenChangeSerializer(AbstractBaseCallbackTokenSerializer):
             user_id = self.context.get('user_id', None)
             user = User.objects.get(**{'id': user_id})
             callback_token = attrs.get('token', None)
+            if alias == getattr(user, alias_type):
+                msg = _(
+                    f'This user already have same {alias_type}.'
+                )
+                raise serializers.ValidationError(msg)
 
             if api_settings.PASSWORDLESS_TEST_MODE:
                 if int(callback_token) in api_settings.PASSWORDLESS_TEST_CODE_INCORRECT:
